@@ -19,26 +19,26 @@ def showInfo(csb, fd=sys.stderr):
     :param fd: file descriptor
     :type fd: :class:`file`
     '''
-    print >> fd, "*", _("%d\taccount(s) read") % len(csb.accounts)
-    print >> fd, "*", _("File properly closed:\t%s") % csb.is_closed()
-    print >> fd, "*", _("%d\trecord(s) read") % csb.abstract.totalRecords
+    print >> fd, "*", (_("%d\taccount(s) read") % len(csb.accounts)).encode('utf-8')
+    print >> fd, "*", (_("File properly closed:\t%s") % csb.is_closed()).encode('utf-8')
+    print >> fd, "*", (_("%d\trecord(s) read") % csb.abstract.totalRecords).encode('utf-8')
     for ac in csb.accounts:
         print >> fd, "*" * 60
-        print >> fd, "* +", _("Account:\t%s\t%s") % (ac.accountNumber, ac.shortName)
-        print >> fd, "*  ", _(" From:\t%s") % ac.initialDate.strftime("%Y-%m-%d")
-        print >> fd, "*  ", _(" To:  \t%s") % ac.finalDate.strftime("%Y-%m-%d")
+        print >> fd, "* +", (_("Account:\t%s\t%s") % (ac.accountNumber, ac.shortName)).encode('utf-8')
+        print >> fd, "*  ", (_(" From:\t%s") % ac.initialDate.strftime("%Y-%m-%d")).encode('utf-8')
+        print >> fd, "*  ", (_(" To:  \t%s") % ac.finalDate.strftime("%Y-%m-%d")).encode('utf-8')
         print >> fd, "*  "
-        print >> fd, "*  ", _("%d\ttransaction(s) read") % len(ac.transactions)
-        print >> fd, "*  ", _("Account properly closed:\t%s") % ac.is_closed()
+        print >> fd, "*  ", (_("%d\ttransaction(s) read") % len(ac.transactions)).encode('utf-8')
+        print >> fd, "*  ", (_("Account properly closed:\t%s") % ac.is_closed()).encode('utf-8')
         print >> fd, "*  "
-        print >> fd, "*  ", _("Previous amount:\t%14.2f\t%s") % \
-            (ac.initialBalance, ac.currency.letter)
-        print >> fd, "*  ", _(" Income:        \t%14.2f\t%s") % \
-            (ac.abstract.income, ac.abstract.currency.letter)
-        print >> fd, "*  ", _(" Expense:       \t%14.2f\t%s") % \
-            (- ac.abstract.expense, ac.abstract.currency.letter)
-        print >> fd, "*  ", _("Balance:        \t%14.2f\t%s") % \
-            (ac.abstract.balance, ac.abstract.currency.letter)
+        print >> fd, "*  ", (_("Previous amount:\t%14.2f\t%s") % \
+            (ac.initialBalance, ac.currency.letter)).encode('utf-8')
+        print >> fd, "*  ", (_(" Income:        \t%14.2f\t%s") % \
+            (ac.abstract.income, ac.abstract.currency.letter)).encode('utf-8')
+        print >> fd, "*  ", (_(" Expense:       \t%14.2f\t%s") % \
+            (- ac.abstract.expense, ac.abstract.currency.letter)).encode('utf-8')
+        print >> fd, "*  ", (_("Balance:        \t%14.2f\t%s") % \
+            (ac.abstract.balance, ac.abstract.currency.letter)).encode('utf-8')
         print >> fd, "*" * 60
 
 
