@@ -5,11 +5,10 @@
     license: GNU Lesser General Public License v3.0 (see LICENSE)
 '''
 
-from csb43.utils import DECIMAL, raiseCsb43Exception, check_strict
+from csb43.utils import DECIMAL, raiseCsb43Exception, check_strict, currencyISO, currencyISOByLetter, isCurrency
 import csb43.utils.messages as msg
 #from csb43.i18n import tr as _
 from record import Record
-import pycountry
 
 import re
 
@@ -114,13 +113,13 @@ class Exchange(Record):
 
     def _get_external_currency_code(self):
         try:
-            return pycountry.currencies.get(numeric=self.__originCurrency)
+            return currencyISO(self.__originCurrency)
         except KeyError:
             return None
 
     def _set_external_currency_code(self, value):
         try:
-            if isinstance(value, pycountry.db.Data):
+            if isCurrency(value):
                 self._set_origin_currency_code(str(value.numeric))
             else:
                 import numbers
@@ -130,9 +129,9 @@ class Exchange(Record):
                     val = str(value)
                 obj = None
                 if self.CUR_NUM.match(val):
-                    obj = pycountry.currencies.get(numeric=val)
+                    obj = currencyISO(val)
                 elif self.CUR_LET.match(val):
-                    obj = pycountry.currencies.get(letter=val.upper())
+                    obj = currencyISOByLetter(val.upper())
                 else:
                     raiseCsb43Exception(msg.CURRENCY_EXPECTED(val), strict=True)
                 if obj:
