@@ -7,7 +7,7 @@
 
 import re
 import datetime
-import pycountry
+#import pycountry
 import sys
 import functools
 
@@ -168,13 +168,54 @@ def date2raw(value, yearFirst = True):
     else:
         raise Csb43Exception(_("instance of datetime or date expected, but '%s' found") % type(value))
 
-def currencyISO(code):
+class CurrencyLite(object):
+
+    def __init__(self, letter, numeric):
+        self.letter = letter
+        self.numeric = numeric
+
+from currency_data import CURRENCY_DATA
+
+__CUR_LETTER = {}
+__CUR_NUMERIC = {}
+
+for el in CURRENCY_DATA:
+    __tmp = CurrencyLite(el[0], el[1])
+    if el[0]:
+        __CUR_LETTER[el[0]] = __tmp
+    if el[1]:
+        __CUR_NUMERIC[el[1]] = __tmp
+
+def currencyISO(numeric):
     '''
     :param code: a ISO 4217 numeric code
     :type  code: :class:`str`
     :rtype: :class:`pycountry.db.Currency` object from its numeric code
     '''
-    return pycountry.currencies.get(numeric=code)
+    if hasattr(sys, 'frozen'):
+        return __CUR_NUMERIC[numeric]
+    else:
+        import pycountry
+        return pycountry.currencies.get(numeric=numeric)
+
+def currencyISOByLetter(letter):
+    '''
+    :param code: a ISO 4217 numeric code
+    :type  code: :class:`str`
+    :rtype: :class:`pycountry.db.Currency` object from its numeric code
+    '''
+    if hasattr(sys, 'frozen'):
+        return __CUR_LETTER[letter]
+    else:
+        import pycountry
+        return pycountry.currencies.get(letter=letter)
+
+def isCurrency(obj):
+    if hasattr(sys, 'frozen'):
+        return isinstance(obj, CurrencyLite)
+    else:
+        import pycountry
+        return isinstance(obj, pycountry.db.Data)
 
 # items
 CONCEPTOS = {
